<?php

namespace Drupal\trinion_base\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\FocusFirstCommand;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Ajax\InvokeCommand;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\Element\EntityAutocomplete;
use Drupal\taxonomy\Entity\Term;
use Drupal\user\Entity\User;
use Symfony\Component\HttpFoundation\JsonResponse;

class InlineChangeFieldController extends ControllerBase {

  public function showField($node, $field_name) {
    $nid = $node->id();
    switch ($field_name) {
      case 'field_tz_ikonka':
        $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadByProperties(['vid' => 'prioritet_zadachi']);
        $options = [];
        foreach ($terms as $term)
          $options[$term->id()] = $term->label();
        $build = [
          '#type' => 'select',
          '#options' => $options,
          '#value' => $node->get('field_tz_prioritet')->getString(),
        ];
        break;
      case 'field_tz_ikonka_1':
        $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadByProperties(['vid' => 'tz_statusy_zadach']);
        $options = [];
        foreach ($terms as $term)
          $options[$term->id()] = $term->label();
        $build = [
          '#type' => 'select',
          '#options' => $options,
          '#value' => $node->get('field_tz_status_zadachi')->getString(),
        ];
        break;
      case 'field_tz_kategoriya_zadachi':
        $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadByProperties(['vid' => 'kategoriya_zadachi']);
        $options = ['' => '-'];
        foreach ($terms as $term) {
          if ($node->get('field_tz_proekt')->getString() == $term->get('field_tz_proekt')->getString())
            $options[$term->id()] = $term->label();
        }
        $build = [
          '#type' => 'select',
          '#options' => $options,
          '#value' => $node->get('field_tz_kategoriya_zadachi')->getString(),
        ];
        break;
      case 'field_tz_otvetstvennyy':
        $options = [];
        $resposible = [];
        foreach ($node->get('field_tz_otvetstvennyy') as $item)
          $resposible[] = $item->entity->id();
        $query = \Drupal::entityQuery('user')
          ->condition('field_tz_proekt', $node->get('field_tz_proekt')->getString())
          ->condition('roles', 't_zadachnik');
        $res = $query->accessCheck()->execute();
        foreach (User::loadMultiple($res) as $user)
          $options[$user->id()] = $user->get('field_tb_nick_name')->getString();
        $build = [
          '#type' => 'select',
          '#attributes' => ['multiple' => 'multiple'],
          '#options' => $options,
          '#value' => $resposible,
        ];
        break;
      default:
        $build = \Drupal::moduleHandler()->invokeAll('trinion_base_inline_show_fields', [$field_name, $node]);
        if (empty($build)) {
          $type = $node->get($field_name)->getFieldDefinition()->getType();
          switch ($type) {
            case 'string':
              $build = [
                '#type' => 'textfield',
                '#value' => $node->get($field_name)->getString(),
              ];
              break;
          }
        }
    }

    $resposne = new AjaxResponse();
    $resposne->addCommand(new HtmlCommand("#{$field_name}-{$nid}", $build));
    $resposne->addCommand(new FocusFirstCommand("#{$field_name}-{$nid}"));
    return $resposne;
  }

  public function changeField($node, $field_name) {
    $nid = $node->id();
    $new_value = \Drupal::request()->get('data');
    switch ($field_name) {
      case 'field_tz_ikonka':
        $node->set('field_tz_prioritet', $new_value);
        $node->save();
        break;
      case 'field_tz_ikonka_1':
        $node->set('field_tz_status_zadachi', $new_value);
        $node->save();
        break;
      case 'field_tz_kategoriya_zadachi':
        if ($new_value) {
          $node->set('field_tz_kategoriya_zadachi', $new_value ? $new_value : NULL);
          $node->save();
        }
        break;
      case 'field_tz_otvetstvennyy':
        switch ($node->bundle()) {
          case 'zadacha':
            $target_field = 'field_tz_otvetstvennyy';
            break;
        }
        if ($target_field) {
          $node->set($target_field, $new_value);
          $node->save();
        }
        break;
      default:
        $build = \Drupal::moduleHandler()->invokeAll('trinion_base_inline_change_fields', [$field_name, $node, $new_value]);
        if (empty($build)) {
          $type = $node->get($field_name)->getFieldDefinition()->getType();
          switch ($type) {
            case 'string':
              $node->set($field_name, $new_value);
              $node->save();
              break;
          }
        }
    }

    $resposne = new AjaxResponse();
    return $resposne;
  }

  public function getValue($node, $field_name) {
    $nid = $node->id();
    $new_value = \Drupal::request()->get('data');
    switch ($field_name) {
      case 'field_tz_ikonka':
        $term = Term::load($new_value);
        $build = $term->get('field_tz_ikonka')->getString();
        break;
      case 'field_tz_ikonka_1':
        $term = Term::load($new_value);
        $build = $term->get('field_tz_ikonka')->getString();
        break;
      case 'field_tz_kategoriya_zadachi':
        if ($new_value) {
          $term = Term::load($new_value);
          $build = $term->label();
        }
        else
          $build = '';
        break;
      case 'field_tz_otvetstvennyy':
        switch ($node->bundle()) {
          case 'zadacha':
            $target_field = 'field_tz_otvetstvennyy';
            break;
        }
        if ($target_field) {
          $build = [];
          foreach ($new_value as $uid) {
            if ($user = User::load($uid)) {
              $build[] = $user->get('field_tb_nick_name')->getString();
            }
          }

          $build = implode(', ', $build);
        }
        else {
          if ($current = $node->get($target_field)->first()) {
            $build = $current->entity->get('field_tb_nick_name')->getString();
          }
        }
        break;
      default:
        $build = \Drupal::moduleHandler()->invokeAll('trinion_base_inline_change_fields', [$field_name, $node, $new_value]);
        if (empty($build)) {
          $type = $node->get($field_name)->getFieldDefinition()->getType();
          switch ($type) {
            case 'string':
              $build = $new_value;
              break;
          }
        }
        else
          $build = reset($build);
    }

    $resposne = new AjaxResponse();
    $resposne->addCommand(new HtmlCommand("#{$field_name}-{$nid}", $build));
    return $resposne;
  }

  public function autocompleteField($node, $field_name) {
    $matches = [];
    $term = \Drupal::request()->get('term');
    switch ($field_name) {
      case 'field_tb_nick_name':
        $query = \Drupal::entityQuery('user')
          ->condition('field_tb_nick_name', $term . '%', 'LIKE');
        $query->range(0, 10);
        $res = $query->accessCheck()->execute();
        foreach (User::loadMultiple($res) as $user) {
          $value = $user->get('field_tb_nick_name')->getString();
          $value .= ' (' . $user->id() . ')';
          $matches[] = [
            'label' => $value,
            'value' => $value,
          ];
        }
        break;
    }
    return new JsonResponse($matches);
  }
}
